@@ -1,6 +1,6 @@
 /* ncdu - NCurses Disk Usage
 
-  Copyright (c) 2007-2018 Yoran Heling
+  Copyright (c) 2007-2019 Yoran Heling
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -67,10 +67,8 @@ static void hlink_check(struct dir *d) {
 
   /* found in the table? update hlnk */
   if(!i) {
-    t = d->hlnk = kh_key(links, k);
-    if(t->hlnk != NULL)
-      for(t=t->hlnk; t->hlnk!=d->hlnk; t=t->hlnk)
-        ;
+    t = kh_key(links, k);
+    d->hlnk = t->hlnk == NULL ? t : t->hlnk;
     t->hlnk = d;
   }
 
@@ -146,10 +144,13 @@ static int item(struct dir *dir, const char *name, struct dir_ext *ext) {
    * possible hard link, because hlnk_check() will take care of it in that
    * case. */
   if(item->flags & FF_HLNKC) {
-    addparentstats(item->parent, 0, 0, 1);
+    addparentstats(item->parent, 0, 0, 0, 1);
     hlink_check(item);
-  } else
-    addparentstats(item->parent, item->size, item->asize, 1);
+  } else if(item->flags & FF_EXT) {
+    addparentstats(item->parent, item->size, item->asize, dir_ext_ptr(item)->mtime, 1);
+  } else {
+    addparentstats(item->parent, item->size, item->asize, 0, 1);
+  }
 
   /* propagate ERR and SERR back up to the root */
   if(item->flags & FF_SERR || item->flags & FF_ERR)
