@@ -1,6 +1,6 @@
 /* ncdu - NCurses Disk Usage
 
-  Copyright (c) 2007-2018 Yoran Heling
+  Copyright (c) 2007-2019 Yoran Heling
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -84,7 +84,7 @@ static void stat_to_dir(struct stat *fs) {
 /* Reads all filenames in the currently chdir'ed directory and stores it as a
  * nul-separated list of filenames. The list ends with an empty filename (i.e.
  * two nuls). . and .. are not included. Returned memory should be freed. *err
- * is set to 1 if some error occured. Returns NULL if that error was fatal.
+ * is set to 1 if some error occurred. Returns NULL if that error was fatal.
  * The reason for reading everything in memory first and then walking through
  * the list is to avoid eating too many file descriptors in a deeply recursive
  * directory. */
@@ -185,7 +185,7 @@ static int dir_scan_recurse(const char *name) {
  * directory. Assumes we're chdir'ed in the directory in which this item
  * resides. */
 static int dir_scan_item(const char *name) {
-  struct stat st;
+  static struct stat st, stl;
   int fail = 0;
 
 #ifdef __CYGWIN__
@@ -204,8 +204,12 @@ static int dir_scan_item(const char *name) {
     dir_setlasterr(dir_curpath);
   }
 
-  if(!(buf_dir->flags & (FF_ERR|FF_EXL)))
-    stat_to_dir(&st);
+  if(!(buf_dir->flags & (FF_ERR|FF_EXL))) {
+    if(follow_symlinks && S_ISLNK(st.st_mode) && !stat(name, &stl) && !S_ISDIR(stl.st_mode))
+      stat_to_dir(&stl);
+    else
+      stat_to_dir(&st);
+  }
 
   if(cachedir_tags && (buf_dir->flags & FF_DIR) && !(buf_dir->flags & (FF_ERR|FF_EXL|FF_OTHFS)))
     if(has_cachedir_tag(buf_dir->name)) {
