@@ -1,6 +1,6 @@
 /* ncdu - NCurses Disk Usage
 
-  Copyright (c) 2007-2018 Yoran Heling
+  Copyright (c) 2007-2019 Yoran Heling
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -50,6 +50,14 @@ static struct dir *parent_alloc, *head, *head_real, *selected, *top = NULL;
   ))
 
 
+static inline int cmp_mtime(struct dir *x, struct dir*y) {
+  int64_t x_mtime = 0, y_mtime = 0;
+  if (x->flags & FF_EXT)
+    x_mtime = dir_ext_ptr(x)->mtime;
+  if (y->flags & FF_EXT)
+    y_mtime = dir_ext_ptr(y)->mtime;
+  return (x_mtime > y_mtime ? 1 : (x_mtime == y_mtime ? 0 : -1));
+}
 
 static int dirlist_cmp(struct dir *x, struct dir *y) {
   int r;
@@ -80,7 +88,8 @@ static int dirlist_cmp(struct dir *x, struct dir *y) {
   r = dirlist_sort_col == DL_COL_NAME ? CMP_NAME :
       dirlist_sort_col == DL_COL_SIZE ? CMP_SIZE :
       dirlist_sort_col == DL_COL_ASIZE ? CMP_ASIZE :
-      CMP_ITEMS;
+      dirlist_sort_col == DL_COL_ITEMS ? CMP_ITEMS :
+      cmp_mtime(x, y);
   /* try 2 */
   if(!r)
     r = dirlist_sort_col == DL_COL_SIZE ? CMP_ASIZE : CMP_SIZE;
@@ -306,7 +315,7 @@ void dirlist_select(struct dir *d) {
  *  1 = selected has moved down
  * -1 = selected has moved up
  * -2 = selected = first item in the list (faster version of '1')
- * -3 = top should be considered as invalid (after sorting or opening an other dir)
+ * -3 = top should be considered as invalid (after sorting or opening another dir)
  * -4 = an item has been deleted
  * -5 = hidden flag has been changed
  *
@@ -371,7 +380,8 @@ void dirlist_set_sort(int col, int desc, int df) {
     dirlist_sort_df = df;
 
   /* sort the list (excluding the parent, which is always on top) */
-  head_real = dirlist_sort(head_real);
+  if(head_real)
+    head_real = dirlist_sort(head_real);
   if(dirlist_parent)
     dirlist_parent->next = head_real;
   else
