@@ -1,6 +1,6 @@
 /* ncdu - NCurses Disk Usage
 
-  Copyright (c) 2007-2018 Yoran Heling
+  Copyright (c) 2007-2019 Yoran Heling
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -45,7 +45,7 @@
 #define FF_DIR    0x01
 #define FF_FILE   0x02
 #define FF_ERR    0x04 /* error while reading this item */
-#define FF_OTHFS  0x08 /* excluded because it was an other filesystem */
+#define FF_OTHFS  0x08 /* excluded because it was another filesystem */
 #define FF_EXL    0x10 /* excluded using exlude patterns */
 #define FF_SERR   0x20 /* error in subdirectory */
 #define FF_HLNKC  0x40 /* hard link candidate (file with st_nlink > 1) */
@@ -103,6 +103,8 @@ extern int cachedir_tags;
 extern int confirm_quit;
 /* flag whether we want to enable use of struct dir_ext */
 extern int extended_info;
+/* flag whether we want to follow symlinks */
+extern int follow_symlinks;
 
 /* handle input from keyboard and update display */
 int input_handle(int);
