@@ -1,6 +1,6 @@
 /* ncdu - NCurses Disk Usage
 
-  Copyright (c) 2007-2018 Yoran Heling
+  Copyright (c) 2007-2019 Yoran Heling
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -41,6 +41,7 @@ int read_only = 0;
 long update_delay = 100;
 int cachedir_tags = 0;
 int extended_info = 0;
+int follow_symlinks = 0;
 
 static int min_rows = 17, min_cols = 60;
 static int ncurses_init = 0;
@@ -103,6 +104,8 @@ int input_handle(int wait) {
     }
     screen_draw();
   }
+  if(errno == EPIPE || errno == EBADF)
+      return 1;
   return 0;
 }
 
@@ -117,9 +120,9 @@ static void argv_parse(int argc, char **argv) {
   char *dir = NULL;
 
   static yopt_opt_t opts[] = {
-    { 'h', 0, "-h,-?" },
+    { 'h', 0, "-h,-?,--help" },
     { 'q', 0, "-q" },
-    { 'v', 0, "-v" },
+    { 'v', 0, "-v,-V,--version" },
     { 'x', 0, "-x" },
     { 'e', 0, "-e" },
     { 'r', 0, "-r" },
@@ -130,6 +133,7 @@ static void argv_parse(int argc, char **argv) {
     { '2', 0, "-2" },
     {  1,  1, "--exclude" },
     { 'X', 1, "-X,--exclude-from" },
+    { 'L', 0, "-L,--follow-symlinks" },
     { 'C', 0, "--exclude-caches" },
     { 's', 0, "--si" },
     { 'Q', 0, "--confirm-quit" },
@@ -146,9 +150,9 @@ static void argv_parse(int argc, char **argv) {
     case  0 : dir = val; break;
     case 'h':
       printf("ncdu <options> <directory>\n\n");
-      printf("  -h                         This help message\n");
+      printf("  -h,--help                  This help message\n");
       printf("  -q                         Quiet mode, refresh interval 2 seconds\n");
-      printf("  -v                         Print version\n");
+      printf("  -v,-V,--version            Print version\n");
       printf("  -x                         Same filesystem\n");
       printf("  -e                         Enable extended information\n");
       printf("  -r                         Read only\n");
@@ -158,6 +162,7 @@ static void argv_parse(int argc, char **argv) {
       printf("  --si                       Use base 10 (SI) prefixes instead of base 2\n");
       printf("  --exclude PATTERN          Exclude files that match PATTERN\n");
       printf("  -X, --exclude-from FILE    Exclude files that match any pattern in FILE\n");
+      printf("  -L, --follow-symlinks      Follow symbolic links (excluding directories)\n");
       printf("  --exclude-caches           Exclude directories containing CACHEDIR.TAG\n");
       printf("  --confirm-quit             Confirm quitting ncdu\n");
       printf("  --color SCHEME             Set color scheme\n");
@@ -183,12 +188,13 @@ static void argv_parse(int argc, char **argv) {
         exit(1);
       }
       break;
+    case 'L': follow_symlinks = 1; break;
     case 'C':
       cachedir_tags = 1;
       break;
     case 'c':
       if(strcmp(val, "off") == 0)  { uic_theme = 0; }
-      if(strcmp(val, "dark") == 0) { uic_theme = 1; }
+      else if(strcmp(val, "dark") == 0) { uic_theme = 1; }
       else {
         fprintf(stderr, "Unknown --color option: %s\n", val);
         exit(1);
